@@ -1,6 +1,8 @@
 import logging
 import time
-#from kafka import KafkaConsumer, KafkaProducer
+
+
+# from kafka import KafkaConsumer, KafkaProducer
 
 
 # idee
@@ -22,23 +24,23 @@ import time
 # -> event stream problem (handle multiple or just one each?)
 # eventstreap processor process producer1, consumer2,
 
-class EventStreamBase(object):
 
+class EventStreamBase(object):
     id = time.time()
     event_string = "events"
     state_separator = "_"
     relation_type_separator = "-"
 
+    kafka_boot_time = 15
     bootstrap_servers = ['kafka:9092']
     group_id = 'worker'
-    topic_name = False
     consumer_timeout_ms = 5000
     api_version = (0, 10)
 
     running = False
 
     config_states = {
-        'raw': {
+        'unlinked': {
             'own_topic': ['discusses', 'crossref']
         },
         'linked': {
@@ -54,7 +56,7 @@ class EventStreamBase(object):
 
     topics = []
 
-    log = "a EventStreamBase " + str(id) + " "
+    log = "EventStreamBase " + str(id) + " "
 
     def __init__(self, id_in):
         self.id = id_in
@@ -82,24 +84,17 @@ class EventStreamBase(object):
             result = result + self.relation_type_separator + relation_type
         return result
 
-
     def get_topic_name_event(self, event):
         state = event.get('state')
         relation_type = event.get('relation_type')
-        result = self.event_string + self.state_separator + state
-
-        # if a relation type is set and has is own topic
-        logging.warning('rt %s, c %s' %(relation_type, self.config_states[state]['own_topic']))
-        if relation_type != '' and relation_type in self.config_states[state]['own_topic']:
-            result = result + self.relation_type_separator + relation_type
-        return result
-
+        return self.get_topic_name(state, relation_type)
 
     def get_topic_name(self, state, relation_type=''):
         result = self.event_string + self.state_separator + state
 
         # if a relation type is set and has is own topic
-        if relation_type != '' and relation_type in self.config_states[state]['own_topic']:
+        if relation_type != '' and 'own_topic' in self.config_states[state] and relation_type in \
+                self.config_states[state]['own_topic']:
             result = result + self.relation_type_separator + relation_type
         return result
 
